@@ -9,20 +9,18 @@ properties of their parent relativistic particle distributions.
 
 """
 
-# Affiliated packages may add whatever they like to this file, but
-# should keep this content at the top.
-# ----------------------------------------------------------------------------
-from ._astropy_init import *
-
-# ----------------------------------------------------------------------------
-
+from . import models
+from .analysis import *
 from .core import *
+from .model_fitter import *
 from .plot import *
 from .utils import *
-from .analysis import *
-from .model_fitter import *
 
-from . import models
+from .version import get_version
+
+__version__ = get_version()
+del get_version
+
 
 try:
     import sherpa
